Names are returned as raw byte vectors to avoid forced string materialization.
Arguments
- index
Index handle returned by
mb_index_load().
Names are returned as raw byte vectors to avoid forced string materialization.
Index handle returned by mb_index_load().